pub struct PedersenCommitment<E: Curve>(/* private fields */);Expand description
compute c = mG + rH where m is the commited value, G is the group generator, H is a random point and r is a blinding value.